# -*- coding: utf-8 -*-
"""
Created on Wed Sep 22 08:46:58 2021

@author: Martin Paul
"""


import os
import glob
import numpy as np
from matplotlib import pyplot as plt
from astropy.io import fits
from scipy import signal

###############################################################################
# 1 Working directory:                                                        #
# 1a) sets the directory and imports txt files                                #
###############################################################################

sourceDir = "C:\\Users\\rtannenb\\Desktop\\SharpCap Captures\\2022-11-25\\Capture\\12_16_34\\" # enter source directory here

if not os.path.isdir(sourceDir):
	raise NotADirectoryError(sourceDir)

###############################################################################
# 1b) .txt import                                                             #
###############################################################################

roiRegion = np.genfromtxt(sourceDir + "roi_region_x_y.txt") # txt file in the same folder as script and sensor data
roiRegion = roiRegion.astype("int")

hotpixels = np.loadtxt(sourceDir + "hotpixels_960_600.txt") # txt file in the same folder as script and sensor data
hotpixels = hotpixels.astype("int") # first value is "y"

x_start = roiRegion[0,0];
x_end = roiRegion[1,0];

y_start = roiRegion[0,1];
y_end = roiRegion[1,1];


###############################################################################
# 1c) .fits import and file search                                            #
###############################################################################

sf = glob.glob(sourceDir + "/*.fits")

print("In total " + str(len(sf)) + " .csv files were found and saved in the sf dictionary!")
if not os.path.isdir(sourceDir):
	raise NotADirectoryError(sourceDir)


for i in range(len(sf)):
    interrim = fits.open(sf[i])[0].data
    
dataFrameDictCold = {} # rawdata with removed


for i in range(len(sf)):
    interrim = fits.open(sf[i])[0].data
    for k in range(len(hotpixels)):
        #print("test")
        interrim[hotpixels[k][1],hotpixels[k][0]] = 0

    dataFrameDictCold[i] = interrim


x, y = np.arange(x_start,x_end,1) , np.arange(y_start,y_end,1)
X, Y = np.meshgrid(x, y)    

###############################################################################
# 2    Data Evaluation with fixed roi                                         #
###############################################################################

evalType = "y"


if evalType == "y":

    results_array = []
    xdata = np.vstack((X.ravel(), Y.ravel()))


    for i in range(len(dataFrameDictCold)):
        
       
        data_post = dataFrameDictCold[i][x_start:x_end,y_start:y_end]
        
        x_center = 1#int(round(popt[0]))-2
        y_center = 1#int(round(popt[1]))+3
       

        interrim = np.mean(np.sort(data_post.flatten()))
        row =interrim
        fit = None
        
        results_array = np.append(results_array,[i,row,x_center,y_center])
        print("file number :" + str(i) + " x = : " + str(x_center) + " y = " + str(y_center) + " mean : " + str(interrim))

    results_array = results_array.reshape(len(dataFrameDictCold),4)
else:
    print("error")

###############################################################################
# 3 Data export                                                               #
###############################################################################

fmt = "\t".join(["%s"] + ["%10.3e"] * (results_array.shape[1]-1))
np.savetxt("Name_of_Experiment.txt", results_array, fmt=fmt, header= # Enter file name for export file
"source directory of the raw data: " +"\n"+
"\n"+
"     " +     sourceDir + "\n" +
"\n"+
"\n"+
"\n"+
"Evaluation specific data: "  "\n" +
"\n"+
"     roi_region (x) :" + str(roiRegion[0,0]) +  "-" + str(roiRegion[1,0]) + "\n"+
"     roi_region (Y) :" + str(roiRegion[0,1]) +  "-" + str(roiRegion[1,1]) + "\n"+

"\n"+
"Columns: "  "\n" +
"     1: frame number " + "\n" +
"     2: mean intensity of the ROI" "\n" +
"     3: x0 center of the roi " "\n" +
"     4: y0_center of the roi" "\n" 
           , comments='')